@@ -4,10 +4,8 @@ import os
 import pynsee
 from pynsee import init_conn
 from pynsee.utils import clear_all_cache
-from dotenv import load_dotenv
 
-load_dotenv()
-init_conn(sirene_key=os.getenv("API_KEY"))
+clear_all_cache()
 
 def run():
     app = FastMCP("insee-server")
@@ -30,13 +28,13 @@ def run():
         Returns:
             dict: Informations clés sur l'entreprise.
         """
+        print("API KEY inside server:", os.getenv("API_KEY"))
         return search_sirene_company(company_name, siren, siret, fuzzy)
 
     # Lancement du serveur avec transport streamable-http
     app.run(transport="streamable-http", host="127.0.0.1", port=9000, path="/mcp")
 
 if __name__ == "__main__":
-    clear_all_cache()
-    print("API_KEY:", os.getenv("API_KEY"))
     
+    print("API_KEY:", os.getenv("API_KEY"))
     run()
